"""SmartLead API schemas."""

from sdk_248.schemas.smartlead.request import (
    AddEmailAccountRequest,
    AddLeadsSettings,
    AddLeadsToCampaignRequest,
    BaseLeadRequest,
    BaseScheduleRequest,
    BaseSettingsRequest,
    CampaignSequenceInput,
    CreateCampaignRequest,
    CreateCampaignSequencesRequest,
    DeleteCampaignRequest,
    EmailSequenceStep,
    MarkCategorizerAsInterestedRequest,
    ReplyEmailThreadRequest,
    SaveCampaignSequenceRequest,
    StopLeadSetting,
    TrackSetting,
    UpdateCampaignMetadataRequest,
    UpdateCampaignScheduleRequest,
    UpdateCampaignSettingsRequest,
    UpdateResponderSequenceRequest,
)
from sdk_248.schemas.smartlead.response import (
    AddEmailAccountResponse,
    AddLeadsResponse,
    BaseCampaignResponse,
    BaseSuccessResponse,
    CampaignResponse,
    CampaignSequenceResponse,
    CampaignStatus as SmartLeadCampaignStatus,
    CreateCampaignResponse,
    CreateCampaignSequencesResponse,
    DeleteCampaignResponse,
    EmailAccountResponse,
    LeadMessageHistoryResponse,
    LeadMessageResponse,
    LeadResponse,
    LeadStatus,
    SaveCampaignSequenceResponse,
    TimezoneInfo,
    UpdateCampaignScheduleResponse,
    UpdateCampaignSettingsResponse,
)
from sdk_248.schemas.smartlead.webhook import (
    CampaignReplyWebhookSchema,
    EmailSentWebhookSchema,
    MessageModel,
    MetadataModel,
)

__all__ = [
    # Request schemas
    "AddEmailAccountRequest",
    "AddLeadsSettings",
    "AddLeadsToCampaignRequest",
    "BaseLeadRequest",
    "BaseScheduleRequest",
    "BaseSettingsRequest",
    "CampaignSequenceInput",
    "CreateCampaignRequest",
    "CreateCampaignSequencesRequest",
    "DeleteCampaignRequest",
    "EmailSequenceStep",
    "MarkCategorizerAsInterestedRequest",
    "ReplyEmailThreadRequest",
    "SaveCampaignSequenceRequest",
    "StopLeadSetting",
    "TrackSetting",
    "UpdateCampaignMetadataRequest",
    "UpdateCampaignScheduleRequest",
    "UpdateCampaignSettingsRequest",
    "UpdateResponderSequenceRequest",
    # Response schemas
    "AddEmailAccountResponse",
    "AddLeadsResponse",
    "BaseCampaignResponse",
    "BaseSuccessResponse",
    "CampaignResponse",
    "CampaignSequenceResponse",
    "SmartLeadCampaignStatus",
    "CreateCampaignResponse",
    "CreateCampaignSequencesResponse",
    "DeleteCampaignResponse",
    "EmailAccountResponse",
    "LeadMessageHistoryResponse",
    "LeadMessageResponse",
    "LeadResponse",
    "LeadStatus",
    "SaveCampaignSequenceResponse",
    "TimezoneInfo",
    "UpdateCampaignScheduleResponse",
    "UpdateCampaignSettingsResponse",
    # Webhook schemas
    "CampaignReplyWebhookSchema",
    "EmailSentWebhookSchema",
    "MessageModel",
    "MetadataModel",
]
